==> gstat_0.9-20.tar.gz: gstat/R/gstat.formula.predict.R <==
"gstat.formula.predict" <-
function (formula, locations, newdata, na.action) 
{
	#if (is(locations, "Spatial")) {
	#	if (!require(sp))
	#		stop("package sp required to deal with Spatial classes")
	#	newdata = locations
	#}
	if (is(newdata, "SpatialRings") && require(sp)) {
		locs = t(sapply(getSRpolygonsSlot(newdata), function(x) getSringsLabptSlot(x)))
		colnames(locs) = c("x", "y")
		if (is(newdata, "SpatialRingsDataFrame"))
			newdata = as.data.frame(newdata)
		else
			newdata = data.frame(a = rep(1, nrow(locs)))
	} else if (has.coordinates(newdata)) {
		locs = coordinates(newdata)
		newdata = as.data.frame(newdata)
	} else {
		# resolve locations:
		terms.l = terms(locations)
    	attr(terms.l, "intercept") = 0
    	mf.locs = model.frame(terms.l, newdata, na.action = na.action)
    	locs = model.matrix(terms.l, mf.locs)
	}

	# resolve formula:
	terms.f = delete.response(terms(formula))
    mf.f = model.frame(terms.f, newdata, na.action = na.action)
    X = model.matrix(terms.f, mf.f)

	if (inherits(locations, "formula") && NROW(locs) != NROW(X)) { 
		# NA's were filtered in one, but not the other:
		mf.locs = model.frame(terms.l, newdata, na.action = na.pass)
    	mf.f =    model.frame(terms.f, newdata, na.action = na.pass)
		valid.pattern = !(apply(cbind(mf.f, mf.locs), 1,
			             function(x) any(is.na(x))))
		X    = model.matrix(terms.f, mf.f   [valid.pattern, , drop = FALSE])
		locs = model.matrix(terms.l, mf.locs[valid.pattern, , drop = FALSE])
		if (NROW(locs) != NROW(X))
			stop("NROW(locs) != NROW(X): this should not occur")
	}
    list(locations = as.matrix(locs), X = as.matrix(X))
}

==> gstat_0.9-22.tar.gz: gstat/R/gstat.formula.predict.R <==
"gstat.formula.predict" <-
function (formula, locations, newdata, na.action) 
{
	#if (is(locations, "Spatial")) {
	#	if (!require(sp))
	#		stop("package sp required to deal with Spatial classes")
	#	newdata = locations
	#}
	if (is(newdata, "SpatialPolygons") && require(sp)) {
		locs = t(sapply(getSpPpolygonsSlot(newdata), function(x) getPolygonsLabptSlot(x)))
		colnames(locs) = c("x", "y")
		if (is(newdata, "SpatialPolygonsDataFrame"))
			newdata = as.data.frame(newdata)
		else
			newdata = data.frame(a = rep(1, nrow(locs)))
	} else if (has.coordinates(newdata)) {
		locs = coordinates(newdata)
		newdata = as.data.frame(newdata)
	} else {
		# resolve locations:
		terms.l = terms(locations)
    	attr(terms.l, "intercept") = 0
    	mf.locs = model.frame(terms.l, newdata, na.action = na.action)
    	locs = model.matrix(terms.l, mf.locs)
	}

	# resolve formula:
	terms.f = delete.response(terms(formula))
    mf.f = model.frame(terms.f, newdata, na.action = na.action)
    X = model.matrix(terms.f, mf.f)

	if (inherits(locations, "formula") && NROW(locs) != NROW(X)) { 
		# NA's were filtered in one, but not the other:
		mf.locs = model.frame(terms.l, newdata, na.action = na.pass)
    	mf.f =    model.frame(terms.f, newdata, na.action = na.pass)
		valid.pattern = !(apply(cbind(mf.f, mf.locs), 1,
			             function(x) any(is.na(x))))
		X    = model.matrix(terms.f, mf.f   [valid.pattern, , drop = FALSE])
		locs = model.matrix(terms.l, mf.locs[valid.pattern, , drop = FALSE])
		if (NROW(locs) != NROW(X))
			stop("NROW(locs) != NROW(X): this should not occur")
	}
    list(locations = as.matrix(locs), X = as.matrix(X))
}
